<?php

namespace Omnipay\SagePay;

/**
 * Sage Pay Server Gateway
 */

use Omnipay\SagePay\Message;

class ServerGateway extends DirectGateway
{
    public function getName()
    {
        return 'Sage Pay Server';
    }

    /**
     * Authorize a payment.
     */
    public function authorize(array $parameters = [])
    {
        return $this->createRequest(Message\ServerAuthorizeRequest::class, $parameters);
    }

    /**
     * Authorize and capture a payment.
     */
    public function purchase(array $parameters = [])
    {
        return $this->createRequest(Message\ServerPurchaseRequest::class, $parameters);
    }

    /**
     * Handle notification callback.
     * Replaces completeAuthorize() and completePurchase()
     */
    public function acceptNotification(array $parameters = [])
    {
        return $this->createRequest(Message\ServerNotifyRequest::class, $parameters);
    }

    /**
     * Accept card details from a user and return a token, without any
     * authorization against that card.
     * i.e. standalone token creation.
     * Alias fof registerToken()
     */
    public function createCard(array $parameters = [])
    {
        return $this->registerToken($parameters);
    }

    /**
     * Accept card details from a user and return a token, without any
     * authorization against that card.
     * i.e. standalone token creation.
     */
    public function registerToken(array $parameters = [])
    {
        return $this->createRequest(Message\ServerTokenRegistrationRequest::class, $parameters);
    }

    /**
     * Handle token registration notification callback.
     * Please now use acceptNotification()
     * @deprecated
     */
    public function completeRegistration(array $parameters = [])
    {
        return $this->createRequest(Message\ServerTokenRegistrationCompleteRequest::class, $parameters);
    }

    /**
     * Handle authorize notification callback.
     * Please now use acceptNotification()
     * @deprecated
     */
    public function completeAuthorize(array $parameters = [])
    {
        return $this->createRequest(Message\ServerCompleteAuthorizeRequest::class, $parameters);
    }

    /**
     * Handle purchase notification callback.
     * Please now use acceptNotification()
     * @deprecated
     */
    public function completePurchase(array $parameters = [])
    {
        return $this->completeAuthorize($parameters);
    }
}
